from latex_input.unicode_structs import (
    CharacterFontVariant, FontVariantType,
)

from latex_input.cached_unicode_data import (
    cached_character_font_variants as character_font_variants,
    cached_subscripts as subscript_mapping,
    cached_superscripts as superscript_mapping
)

# Manual fixes
superscript_mapping["α"] = "ᵅ"
superscript_mapping["ϵ"] = "ᵋ"
superscript_mapping["ι"] = "ᶥ"
superscript_mapping["ϕ"] = "ᶲ"

# Planck's constant already fulfills this role, but isn't detected
character_font_variants["h"].append(
    CharacterFontVariant(
        text="\u210E",
        kind=FontVariantType.ITALIC | FontVariantType.MATHEMATICAL
    )
)

latex_symbols: dict[str, str] = {
    # Greek letters -- the big list on the bottom was missing some
    "Alpha":    "\u0391",
    "Beta":     "\u0392",
    "Gamma":    "\u0393",
    "Delta":    "\u0394",
    "Epsilon":  "\u0395",
    "Zeta":     "\u0396",
    "Eta":      "\u0397",
    "Theta":    "\u0398",
    "Iota":     "\u0399",
    "Kappa":    "\u039A",
    "Lambda":   "\u039B",
    "Mu":       "\u039C",
    "Nu":       "\u039D",
    "Xi":       "\u039E",
    "Omicron":  "\u039F",
    "Pi":       "\u03A0",
    "Rho":      "\u03A1",
    "Sigma":    "\u03A3",
    "Tau":      "\u03A4",
    "Upsilon":  "\u03A5",
    "Phi":      "\u03A6",
    "Chi":      "\u03A7",
    "Psi":      "\u03A8",
    "Omega":    "\u03A9",
    "alpha":    "\u03B1",
    "beta":     "\u03B2",
    "gamma":    "\u03B3",
    "delta":    "\u03B4",
    "epsilon":  "\u03F5",  # NOTE: This is the lunate form by default. Varepsilon is the reversed-3
    "zeta":     "\u03B6",
    "eta":      "\u03B7",
    "theta":    "\u03B8",
    "iota":     "\u03B9",
    "kappa":    "\u03BA",
    "lambda":   "\u03BB",
    "mu":       "\u03BC",
    "nu":       "\u03BD",
    "xi":       "\u03BE",
    "omicron":  "\u03BF",
    "pi":       "\u03C0",
    "rho":      "\u03C1",
    "sigma":    "\u03C3",
    "tau":      "\u03C4",
    "upsilon":  "\u03C5",
    "phi":      "\u03D5",  # NOTE: This is the closed form by default. Varphi is the open form
    "chi":      "\u03C7",
    "psi":      "\u03C8",
    "omega":    "\u03C9",

    # Greek letter variants
    "varepsilon":   "\u03B5",  # ε
    "vartheta":     "\u03D1",  # ϑ
    "varpi":        "\u03D6",  # ϖ
    "varrho":       "\u03F1",  # ϱ
    "varsigma":     "\u03C2",  # ς
    "varphi":       "\u03C6",  # φ

    # Personal additions
    "iff": "⟺",
    "nmodels": "⊭",
    "models": "⊨",
    "coda": "𝄌",
    "segno": "𝄋",

    # Number set shorthands (mathbb) -- useful but non-standard
    "Complex":      "\u2102",  # ℂ
    "N":            "\u2115",  # ℕ
    "Q":            "\u211A",  # ℚ
    "R":            "\u211D",  # ℝ
    "Z":            "\u2124",  # ℤ

    # Mathematical spacing symbols
    # This combination of 4/18 + [1/16..1/10] is as close as it gets to the 5/18 em definition
    "thickmuskip":  "\u205F\u200A",     # = \; = 5mu = 5/18em ≈ MEDIUM U+205F + HAIR SPACE U+200A
    "medmuskip":    "\u205F",           # = \: = 4mu = 4/18em = MEDIUM MATHEMATICAL SPACE U+205F
    "thinmuskip":   "\u2006",           # = \, = 3mu = 3/18em = 1/6em = SIX-PER-EM SPACE U+2006

    # Below are additions to the huge list on the bottom from
    # https://github.com/clarkgrubb/latex-input/blob/master/data/latex/unicode.txt
    "bigodot": "⊙",
    "trademark": "™",
    "square": "□",
    "Omicron": "Ο",
    "bigsqcup": "⊔",
    "rhd": "⊳",
    "centerdot": "⋅",
    "circledS": "Ⓢ",
    "copyright": "©",
    "longleftrightarrow": "↔",
    "surd": "√",
    "cents": "¢",
    "triangle": "△",
    "Longleftrightarrow": "⇔",
    "textregistered": "®",
    "bigcirc": "○",
    "setminus": "∖",
    "unlhd": "⊴",
    "triangleright": "▷",
    "unrhd": "⊵",
    "thickapprox": "≈",
    "pound": "£",
    "succeq": "≽",
    "backepsilon": "∍",
    "doteqdot": "≑",
    "smallfrown": "⌢",
    "partial": "∂",
    "digamma": "Ϝ",
    "shortparallel": "∥",
    "leadsto": "↝",
    "bigotimes": "⊗",
    "pilcrow": "¶",
    "smallsmile": "⌣",
    "space": "␣",
    "Join": "⋈",
    "perp": "⊥",
    "ge": "≥",
    "blacktriangledown": "▼",
    "triangledown": "▽",
    "longmapsto": "⇖",
    "longrightarrow": "→",
    "texttrademark": "™",
    "bigoplus": "⊕",
    "biguplus": "⊎",
    "hbar": "ℏ",
    "section": "§",
    "le": "≤",
    "vartriangle": "△",
    "omicron": "ο",
    "longleftarrow": "←",
    "preceq": "≼",
    "varpropto": "∝",
    "blacktriangle": "▲",
    "triangleleft": "◁",
    "Box": "□",
    "lhd": "⊲",
    "Longrightarrow": "⇒",
    "registered": "®",
    "blacktriangleleft": "◀",
    "thicksim": "∼",
    "implies": "⇒",
    "blacksquare": "■",
    "blacklozenge": "◆",
    "degree": "°",
    "leqslant": "≤",
    "blacktriangleright": "▷",
    "epsilon": "∊",
    "Longleftarrow": "⇐",


    # Below is a huge list adapted from:
    # https://github.com/joom/latex-unicoder.vim/blob/master/autoload/unicoder.vim
    "lbrack": "[",
    "backslash": "\\",
    "rbrack": "]",
    "{": "{",
    "}": "}",
    "sptilde": "~",
    "cent": "¢",
    "pounds": "£",
    "yen": "¥",
    "spddot": "¨",
    "neg": "¬",
    "lnot": "¬",
    "circledR": "®",
    "pm": "±",
    "Micro": "µ",
    "cdotp": "·",
    "times": "×",
    "eth": "ð",
    "div": "÷",
    "imath": "𝚤",
    "Zbar": "Ƶ",
    "jmath": "𝚥",
    "Alpha": 'Α',
    "Beta": 'Β',
    "Gamma": 'Γ',
    "Delta": 'Δ',
    "Epsilon": 'Ε',
    "Zeta": 'Ζ',
    "Eta": 'Η',
    "Theta": 'Θ',
    "Iota": 'Ι',
    "Kappa": 'Κ',
    "Lambda": 'Λ',
    "upMu": 'Μ',
    "upNu": 'Ν',
    "Xi": 'Ξ',
    "upOmicron": 'Ο',
    "Pi": 'Π',
    "Rho": 'Ρ',
    "Sigma": 'Σ',
    "Tau": 'Τ',
    "Upsilon": 'Υ',
    "Phi": 'Φ',
    "Chi": 'Χ',
    "Psi": 'Ψ',
    "Omega": 'Ω',
    "alpha": 'α',
    "beta": 'β',
    "gamma": 'γ',
    "delta": 'δ',
    "upepsilon": 'ε',
    "zeta": 'ζ',
    "eta": 'η',
    "theta": 'θ',
    "iota": 'ι',
    "kappa": 'κ',
    "lambda": 'λ',
    "mu": 'μ',
    "nu": 'ν',
    "xi": 'ξ',
    "upomicron": 'ο',
    "pi": 'π',
    "rho": 'ρ',
    "varsigma": 'ς',
    "sigma": 'σ',
    "tau": 'τ',
    "upsilon": 'υ',
    "varphi": 'φ',
    "chi": 'χ',
    "psi": 'ψ',
    "omega": 'ω',
    "upvarbeta": 'ϐ',
    "vartheta": 'ϑ',
    "phi": 'ϕ',
    "varpi": 'ϖ',
    "upoldKoppa": 'Ϙ',
    "upoldkoppa": 'ϙ',
    "Stigma": 'Ϛ',
    "upstigma": 'ϛ',
    "Digamma": 'Ϝ',
    "digamma": 'ϝ',
    "Koppa": 'Ϟ',
    "upkoppa": 'ϟ',
    "Sampi": 'Ϡ',
    "upsampi": 'ϡ',
    "varkappa": 'ϰ',
    "varrho": 'ϱ',
    "textTheta": 'ϴ',
    "epsilon": 'ϵ',
    "varepsilon": 'ε',
    "backepsilon": '϶',
    "quad": " ",
    "horizbar": "―",
    "|": "‖",
    "twolowline": "‗",
    "dagger": "†",
    "ddagger": "‡",
    "smblkcircle": "•",
    "enleadertwodots": "‥",
    "ldots": "…",
    "prime": "′",
    "second": "″",
    "third": "‴",
    "backprime": "‵",
    "backdprime": "‶",
    "backtrprime": "‷",
    "caretinsert": "‸",
    "Exclam": "‼",
    "cat": "⁀",
    "hyphenbullet": "⁃",
    "fracslash": "⁄",
    "Question": "⁇",
    "closure": "⁐",
    "fourth": "⁗",
    # ":": " ",
    "euro": "€",
    "lvec": "\u20D6",  # ERROR: They used "\u20D0"
    "vec": "\u20D7",
    "vertoverlay": "\u20D2",
    "LVec": "\u20D6",
    "dddot": "\u20DB",
    "ddddot": "\u20DC",
    "enclosecircle": "\u20DD",
    "enclosesquare": "\u20DE",
    "enclosediamond": "\u20DF",
    "overleftrightarrow": "\u20E1",
    "enclosetriangle": "\u20E4",
    "annuity": "\u20E7",
    "threeunderdot": "\u20E8",
    "widebridgeabove": "\u20E9",
    "underrightharpoondown": "\u20EC",
    "underleftharpoondown": "\u20ED",
    "underleftarrow": "\u20EE",
    "underrightarrow": "\u20EF",
    "asteraccent": "\u20F0",
    "mathbb{C}": "ℂ",
    "Euler": "ℇ",
    "mathcal{g}": "ℊ",
    "mathcal{H}": "ℋ",
    "mathfrak{H}": "ℌ",
    "mathbb{H}": "ℍ",
    "Planckconst": "ℎ",
    "hslash": "ℏ",
    "mathcal{I}": "ℐ",
    "Im": "ℑ",
    "mathcal{L}": "ℒ",
    "ell": "ℓ",
    "mathbb{N}": "ℕ",
    "wp": "℘",
    "mathbb{P}": "ℙ",
    "mathbb{Q}": "ℚ",
    "mathcal{R}": "ℛ",
    "Re": "ℜ",
    "mathbb{R}": "ℝ",
    "mathbb{Z}": "ℤ",
    "tcohm": "Ω",
    "mho": "℧",
    "mathfrak{Z}": "ℨ",
    "turnediota": "℩",
    "Angstroem": "Å",
    "mathcal{B}": "ℬ",
    "mathfrak{C}": "ℭ",
    "mathcal{e}": "ℯ",
    "mathcal{E}": "ℰ",
    "mathcal{F}": "ℱ",
    "Finv": "Ⅎ",
    "mathcal{M}": "ℳ",
    "mathcal{o}": "ℴ",
    "aleph": "ℵ",
    "beth": "ℶ",
    "gimel": "ℷ",
    "daleth": "ℸ",
    "mathbb{\\pi}": "ℼ",
    "mathbb{\\gamma}": "ℽ",
    "mathbb{\\Gamma}": "ℾ",
    "mathbb{\\Pi}": "ℿ",
    "mathbb{\\Sigma}": "⅀",
    "Game": "⅁",
    "sansLturned": "⅂",
    "sansLmirrored": "⅃",
    "Yup": "⅄",
    "CapitalDifferentialD": "ⅅ",
    "DifferentialD": "ⅆ",
    "ExponetialE": "ⅇ",
    "ComplexI": "ⅈ",
    "ComplexJ": "ⅉ",
    "PropertyLine": "⅊",
    "invamp": "⅋",
    "leftarrow": "←",
    "uparrow": "↑",
    "rightarrow": "→",
    "to": "→",
    "downarrow": "↓",
    "leftrightarrow": "↔",
    "updownarrow": "↕",
    "nwarrow": "↖",
    "nearrow": "↗",
    "searrow": "↘",
    "swarrow": "↙",
    "nleftarrow": "↚",
    "nrightarrow": "↛",
    "leftwavearrow": "↜",
    "rightwavearrow": "↝",
    "twoheadleftarrow": "↞",
    "twoheaduparrow": "↟",
    "twoheadrightarrow": "↠",
    "twoheaddownarrow": "↡",
    "leftarrowtail": "↢",
    "rightarrowtail": "↣",
    "mapsfrom": "↤",
    "MapsUp": "↥",
    "mapsto": "↦",
    "MapsDown": "↧",
    "updownarrowbar": "↨",
    "hookleftarrow": "↩",
    "hookrightarrow": "↪",
    "looparrowleft": "↫",
    "looparrowright": "↬",
    "leftrightsquigarrow": "↭",
    "nleftrightarrow": "↮",
    "lightning": "↯",
    "Lsh": "↰",
    "Rsh": "↱",
    "dlsh": "↲",
    "drsh": "↳",
    "linefeed": "↴",
    "carriagereturn": "↵",
    "curvearrowleft": "↶",
    "curvearrowright": "↷",
    "barovernorthwestarrow": "↸",
    "barleftarrowrightarrowba": "↹",
    "circlearrowleft": "↺",
    "circlearrowright": "↻",
    "leftharpoonup": "↼",
    "leftharpoondown": "↽",
    "upharpoonright": "↾",
    "upharpoonleft": "↿",
    "rightharpoonup": "⇀",
    "rightharpoondown": "⇁",
    "downharpoonright": "⇂",
    "downharpoonleft": "⇃",
    "rightleftarrows": "⇄",
    "updownarrows": "⇅",
    "leftrightarrows": "⇆",
    "leftleftarrows": "⇇",
    "upuparrows": "⇈",
    "rightrightarrows": "⇉",
    "downdownarrows": "⇊",
    "leftrightharpoons": "⇋",
    "rightleftharpoons": "⇌",
    "nLeftarrow": "⇍",
    "nLeftrightarrow": "⇎",
    "nRightarrow": "⇏",
    "Leftarrow": "⇐",
    "Uparrow": "⇑",
    "Rightarrow": "⇒",
    "Downarrow": "⇓",
    "Leftrightarrow": "⇔",
    "Updownarrow": "⇕",
    "Nwarrow": "⇖",
    "Nearrow": "⇗",
    "Searrow": "⇘",
    "Swarrow": "⇙",
    "Lleftarrow": "⇚",
    "Rrightarrow": "⇛",
    "leftsquigarrow": "⇜",
    "rightsquigarrow": "⇝",
    "nHuparrow": "⇞",
    "nHdownarrow": "⇟",
    "dashleftarrow": "⇠",
    "updasharrow": "⇡",
    "dashrightarrow": "⇢",
    "downdasharrow": "⇣",
    "LeftArrowBar": "⇤",
    "RightArrowBar": "⇥",
    "leftwhitearrow": "⇦",
    "upwhitearrow": "⇧",
    "rightwhitearrow": "⇨",
    "downwhitearrow": "⇩",
    "whitearrowupfrombar": "⇪",
    "mathord": "⍹",
    "circleonrightarrow": "⇴",
    "downuparrows": "⇵",
    "rightthreearrows": "⇶",
    "nvleftarrow": "⇷",
    "pfun": "⇸",
    "nvleftrightarrow": "⇹",
    "nVleftarrow": "⇺",
    "ffun": "⇻",
    "nVleftrightarrow": "⇼",
    "leftarrowtriangle": "⇽",
    "rightarrowtriangle": "⇾",
    "leftrightarrowtriangle": "⇿",
    "forall": "∀",
    "complement": "∁",
    "partial": "𝜕",
    "exists": "∃",
    "nexists": "∄",
    "varnothing": "∅",
    "emptyset": "∅",
    "increment": "∆",
    "nabla": "∇",
    "in": "∈",
    "notin": "∉",
    "smallin": "∊",
    "ni": "∋",
    "nni": "∌",
    "smallni": "∍",
    "QED": "∎",
    "prod": "∏",
    "coprod": "∐",
    "sum": "∑",
    # "-": "−",
    "mp": "∓",
    "dotplus": "∔",
    "slash": "∕",
    "smallsetminus": "∖",
    "ast": "∗",
    "circ": "∘",
    "bullet": "∙",
    "sqrt": "√",
    "sqrt[3]": "∛",
    "sqrt[4]": "∜",
    "propto": "∝",
    "infty": "∞",
    "rightangle": "∟",
    "angle": "∠",
    "measuredangle": "∡",
    "sphericalangle": "∢",
    "mid": "∣",
    "nmid": "∤",
    "parallel": "∥",
    "nparallel": "∦",
    "wedge": "∧",
    "vee": "∨",
    "land": "∧",
    "lor": "∨",
    "cap": "∩",
    "cup": "∪",
    "int": "∫",
    "iint": "∬",
    "iiint": "∭",
    "oint": "∮",
    "oiint": "∯",
    "oiiint": "∰",
    "intclockwise": "∱",
    "varointclockwise": "∲",
    "ointctrclockwise": "∳",
    "therefore": "∴",
    "because": "∵",
    "Proportion": "∷",
    "dotminus": "∸",
    "eqcolon": "≕",
    "dotsminusdots": "∺",
    "kernelcontraction": "∻",
    "sim": "∼",
    "backsim": "∽",
    "invlazys": "∾",
    "AC": "∿",
    "wr": "≀",
    "nsim": "≁",
    "eqsim": "≂",
    "simeq": "≃",
    "nsimeq": "≄",
    "cong": "≅",
    "simneqq": "≆",
    "ncong": "≇",
    "approx": "≈",
    "napprox": "≉",
    "approxeq": "≊",
    "approxident": "≋",
    "backcong": "≌",
    "asymp": "≍",
    "Bumpeq": "≎",
    "bumpeq": "≏",
    "doteq": "≐",
    "Doteq": "≑",
    "fallingdotseq": "≒",
    "risingdotseq": "≓",
    "coloneq": "≔",
    "eqcirc": "≖",
    "circeq": "≗",
    "arceq": "≘",
    "corresponds": "≙",
    "veeeq": "≚",
    "stareq": "≛",
    "triangleq": "≜",
    "eqdef": "≝",
    "measeq": "≞",
    "questeq": "≟",
    "neq": "≠",
    "not\\eq": "≠",
    "equiv": "≡",
    "nequiv": "≢",
    "Equiv": "≣",
    "leq": "≤",
    "geq": "≥",
    "leqq": "≦",
    "geqq": "≧",
    "lneqq": "≨",
    "gneqq": "≩",
    "ll": "≪",
    "gg": "≫",
    "between": "≬",
    "notasymp": "≭",
    "nless": "≮",
    "ngtr": "≯",
    "nleq": "≰",
    "ngeq": "≱",
    "lesssim": "≲",
    "gtrsim": "≳",
    "NotLessTilde": "≴",
    "NotGreaterTilde": "≵",
    "lessgtr": "≶",
    "gtrless": "≷",
    "nlessgtr": "≸",
    "NotGreaterLess": "≹",
    "prec": "≺",
    "succ": "≻",
    "preccurlyeq": "≼",
    "succcurlyeq": "≽",
    "precsim": "≾",
    "succsim": "≿",
    "nprec": "⊀",
    "nsucc": "⊁",
    "subset": "⊂",
    "supset": "⊃",
    "nsubset": "⊄",
    "nsupset": "⊅",
    "subseteq": "⊆",
    "supseteq": "⊇",
    "nsubseteq": "⊈",
    "nsupseteq": "⊉",
    "subsetneq": "⊊",
    "supsetneq": "⊋",
    "cupleftarrow": "⊌",
    "cupdot": "⊍",
    "uplus": "⊎",
    "sqsubset": "⊏",
    "sqsupset": "⊐",
    "sqsubseteq": "⊑",
    "sqsupseteq": "⊒",
    "sqcap": "⊓",
    "sqcup": "⊔",
    "oplus": "⊕",
    "ominus": "⊖",
    "otimes": "⊗",
    "oslash": "⊘",
    "odot": "⊙",
    "circledcirc": "⊚",
    "circledast": "⊛",
    "circledequal": "⊜",
    "circleddash": "⊝",
    "boxplus": "⊞",
    "boxminus": "⊟",
    "boxtimes": "⊠",
    "boxdot": "⊡",
    "vdash": "⊢",
    "dashv": "⊣",
    "top": "⊤",
    "bot": "⊥",
    "assert": "⊦",
    "models": "⊧",
    "vDash": "⊨",
    "Vdash": "⊩",
    "Vvdash": "⊪",
    "VDash": "⊫",
    "nvdash": "⊬",
    "nvDash": "⊭",
    "nVdash": "⊮",
    "nVDash": "⊯",
    "prurel": "⊰",
    "scurel": "⊱",
    "vartriangleleft": "⊲",
    "vartriangleright": "⊳",
    "trianglelefteq": "⊴",
    "trianglerighteq": "⊵",
    "multimapdotbothA": "⊶",
    "multimapdotbothB": "⊷",
    "multimap": "⊸",
    "hermitmatrix": "⊹",
    "intercal": "⊺",
    "veebar": "⊻",
    "barwedge": "⊼",
    "barvee": "⊽",
    "measuredrightangle": "⊾",
    "varlrtriangle": "⊿",
    "bigwedge": "⋀",
    "bigvee": "⋁",
    "bigcap": "⋂",
    "bigcup": "⋃",
    "diamond": "⋄",
    "cdot": "⋅",
    "star": "⋆",
    "divideontimes": "⋇",
    "bowtie": "⋈",
    "ltimes": "⋉",
    "rtimes": "⋊",
    "leftthreetimes": "⋋",
    "rightthreetimes": "⋌",
    "backsimeq": "⋍",
    "curlyvee": "⋎",
    "curlywedge": "⋏",
    "Subset": "⋐",
    "Supset": "⋑",
    "Cap": "⋒",
    "Cup": "⋓",
    "pitchfork": "⋔",
    "hash": "⋕",
    "lessdot": "⋖",
    "gtrdot": "⋗",
    "lll": "⋘",
    "ggg": "⋙",
    "lesseqgtr": "⋚",
    "gtreqless": "⋛",
    "eqless": "⋜",
    "eqgtr": "⋝",
    "curlyeqprec": "⋞",
    "curlyeqsucc": "⋟",
    "npreceq": "⋠",
    "nsucceq": "⋡",
    "nsqsubseteq": "⋢",
    "nsqsupseteq": "⋣",
    "sqsubsetneq": "⋤",
    "sqsupsetneq": "⋥",
    "lnsim": "⋦",
    "gnsim": "⋧",
    "precnsim": "⋨",
    "succnsim": "⋩",
    "ntriangleleft": "⋪",
    "ntriangleright": "⋫",
    "ntrianglelefteq": "⋬",
    "ntrianglerighteq": "⋭",
    "vdots": "⋮",
    "cdots": "⋯",
    "iddots": "⋰",
    "ddots": "⋱",
    "disin": "⋲",
    "varisins": "⋳",
    "isins": "⋴",
    "isindot": "⋵",
    "barin": "⋶",
    "isinobar": "⋷",
    "isinvb": "⋸",
    "isinE": "⋹",
    "nisd": "⋺",
    "varnis": "⋻",
    "nis": "⋼",
    "varniobar": "⋽",
    "niobar": "⋾",
    "bagmember": "⋿",
    "diameter": "⌀",
    "house": "⌂",
    "varbarwedge": "⌅",
    "vardoublebarwedge": "⌆",
    "lceil": "⌈",
    "rceil": "⌉",
    "lfloor": "⌊",
    "rfloor": "⌋",
    "invneg": "⌐",
    "wasylozenge": "⌑",
    "profline": "⌒",
    "profsurf": "⌓",
    "viewdata": "⌗",
    "turnednot": "⌙",
    "ulcorner": "⌜",
    "urcorner": "⌝",
    "llcorner": "⌞",
    "lrcorner": "⌟",
    "inttop": "⌠",
    "intbottom": "⌡",
    "frown": "⌢",
    "smile": "⌣",
    "varhexagonlrbonds": "⌬",
    "conictaper": "⌲",
    "topbot": "⌶",
    "APLinv": "⌹",
    "obar": "⌽",
    "notslash": "⌿",
    "notbackslash": "⍀",
    "APLleftarrowbox": "⍇",
    "APLrightarrowbox": "⍈",
    "APLuparrowbox": "⍐",
    "APLboxupcaret": "⍓",
    "APLdownarrowbox": "⍗",
    "APLcomment": "⍝",
    "APLinput": "⍞",
    "APLlog": "⍟",
    "APLboxquestion": "⍰",
    "rangledownzigzagarrow": "⍼",
    "hexagon": "⎔",
    "lparenuend": "⎛",
    "lparenextender": "⎜",
    "lparenlend": "⎝",
    "rparenuend": "⎞",
    "rparenextender": "⎟",
    "rparenlend": "⎠",
    "lbrackuend": "⎡",
    "lbrackextender": "⎢",
    "lbracklend": "⎣",
    "rbrackuend": "⎤",
    "rbrackextender": "⎥",
    "rbracklend": "⎦",
    "lbraceuend": "⎧",
    "lbracemid": "⎨",
    "lbracelend": "⎩",
    "vbraceextender": "⎪",
    "rbraceuend": "⎫",
    "rbracemid": "⎬",
    "rbracelend": "⎭",
    "intextender": "⎮",
    "harrowextender": "⎯",
    "lmoustache": "⎰",
    "rmoustache": "⎱",
    "sumtop": "⎲",
    "sumbottom": "⎳",
    "overbracket": "⎴",
    "underbracket": "⎵",
    "bbrktbrk": "⎶",
    "sqrtbottom": "⎷",
    "lvboxline": "⎸",
    "rvboxline": "⎹",
    "varcarriagereturn": "⏎",
    "overparen": "⏜",
    "underparen": "⏝",
    "overbrace": "⏞",
    "underbrace": "⏟",
    "obrbrak": "⏠",
    "ubrbrak": "⏡",
    "trapezium": "⏢",
    "benzenr": "⏣",
    "strns": "⏤",
    "fltns": "⏥",
    "accurrent": "⏦",
    "elinters": "⏧",
    "bdtriplevdash": "┆",
    "blockuphalf": "▀",
    "blocklowhalf": "▄",
    "blockfull": "█",
    "blocklefthalf": "▌",
    "blockrighthalf": "▐",
    "blockqtrshaded": "░",
    "blockhalfshaded": "▒",
    "blockthreeqtrshaded": "▓",
    "mdlgblksquare": "■",
    "mdlgwhtsquare": "□",
    "squoval": "▢",
    "blackinwhitesquare": "▣",
    "squarehfill": "▤",
    "squarevfill": "▥",
    "squarehvfill": "▦",
    "squarenwsefill": "▧",
    "squareneswfill": "▨",
    "squarecrossfill": "▩",
    "smblksquare": "▪",
    "smwhtsquare": "▫",
    "hrectangleblack": "▬",
    "hrectangle": "▭",
    "vrectangleblack": "▮",
    "vrectangle": "▯",
    "parallelogramblack": "▰",
    "parallelogram": "▱",
    "bigblacktriangleup": "▲",
    "bigtriangleup": "△",
    "blacktriangleup": "▴",
    "smalltriangleup": "▵",
    "RHD": "▶",
    "rhd": "▷",
    "blacktriangleright": "▸",
    "smalltriangleright": "▹",
    "blackpointerright": "►",
    "whitepointerright": "▻",
    "bigblacktriangledown": "▼",
    "bigtriangledown": "▽",
    "blacktriangledown": "▾",
    "smalltriangledown": "▿",
    "LHD": "◀",
    "lhd": "◁",
    "blacktriangleleft": "◂",
    "smalltriangleleft": "◃",
    "blackpointerleft": "◄",
    "whitepointerleft": "◅",
    "Diamondblack": "◆",
    "Diamond": "◇",
    "blackinwhitediamond": "◈",
    "fisheye": "◉",
    "lozenge": "◊",
    "Circle": "○",
    "dottedcircle": "◌",
    "circlevertfill": "◍",
    "bullseye": "◎",
    "CIRCLE": "●",
    "LEFTcircle": "◐",
    "RIGHTcircle": "◑",
    "circlebottomhalfblack": "◒",
    "circletophalfblack": "◓",
    "circleurquadblack": "◔",
    "blackcircleulquadwhite": "◕",
    "LEFTCIRCLE": "◖",
    "RIGHTCIRCLE": "◗",
    "inversebullet": "◘",
    "inversewhitecircle": "◙",
    "invwhiteupperhalfcircle": "◚",
    "invwhitelowerhalfcircle": "◛",
    "ularc": "◜",
    "urarc": "◝",
    "lrarc": "◞",
    "llarc": "◟",
    "topsemicircle": "◠",
    "botsemicircle": "◡",
    "lrblacktriangle": "◢",
    "llblacktriangle": "◣",
    "ulblacktriangle": "◤",
    "urblacktriangle": "◥",
    "smwhtcircle": "◦",
    "squareleftblack": "◧",
    "squarerightblack": "◨",
    "squareulblack": "◩",
    "squarelrblack": "◪",
    "boxbar": "◫",
    "trianglecdot": "◬",
    "triangleleftblack": "◭",
    "trianglerightblack": "◮",
    "lgwhtcircle": "◯",
    "squareulquad": "◰",
    "squarellquad": "◱",
    "squarelrquad": "◲",
    "squareurquad": "◳",
    "circleulquad": "◴",
    "circlellquad": "◵",
    "circlelrquad": "◶",
    "circleurquad": "◷",
    "ultriangle": "◸",
    "urtriangle": "◹",
    "lltriangle": "◺",
    # "square": "⬜", # ERROR: This should not be filled
    "blacksquare": "⬛",
    "mdsmwhtsquare": "◽",
    "mdsmblksquare": "◾",
    "lrtriangle": "◿",
    "bigstar": "★",
    "bigwhitestar": "☆",
    "Sun": "☉",
    "Square": "☐",
    "CheckedBox": "☑",
    "XBox": "☒",
    "steaming": "☕",
    "pointright": "☞",
    "skull": "☠",
    "danger": "☡",
    "radiation": "☢",
    "biohazard": "☣",
    "yinyang": "☯",
    "frownie": "☹",
    "smiley": "☺",
    "blacksmiley": "☻",
    "sun": "☼",
    "rightmoon": "☽",
    "leftmoon": "☾",
    "mercury": "☿",
    "female": "♀",
    "earth": "♁",
    "male": "♂",
    "jupiter": "♃",
    "saturn": "♄",
    "uranus": "♅",
    "neptune": "♆",
    "pluto": "♇",
    "aries": "♈",
    "taurus": "♉",
    "gemini": "♊",
    "cancer": "♋",
    "leo": "♌",
    "virgo": "♍",
    "libra": "♎",
    "scorpio": "♏",
    "sagittarius": "♐",
    "capricornus": "♑",
    "aquarius": "♒",
    "pisces": "♓",
    "spadesuit": "♠",
    "heartsuit": "♡",
    "diamondsuit": "♢",
    "clubsuit": "♣",
    "varspadesuit": "♤",
    "varheartsuit": "♥",
    "vardiamondsuit": "♦",
    "varclubsuit": "♧",
    "quarternote": "♩",
    "eighthnote": "♪",
    "twonotes": "♫",
    "sixteenthnote": "♬",
    "flat": "♭",
    "natural": "♮",
    "sharp": "♯",
    "recycle": "♻",
    "acidfree": "♾",
    "dicei": "⚀",
    "diceii": "⚁",
    "diceiii": "⚂",
    "diceiv": "⚃",
    "dicev": "⚄",
    "dicevi": "⚅",
    "circledrightdot": "⚆",
    "circledtwodots": "⚇",
    "blackcircledrightdot": "⚈",
    "blackcircledtwodots": "⚉",
    "anchor": "⚓",
    "swords": "⚔",
    "warning": "⚠",
    "Hermaphrodite": "⚥",
    "medcirc": "⚪",
    "medbullet": "⚫",
    "mdsmwhtcircle": "⚬",
    "neuter": "⚲",
    "pencil": "✎",
    "checkmark": "✓",
    "ballotx": "✗",
    "maltese": "✠",
    "circledstar": "✪",
    "varstar": "✶",
    "dingasterisk": "✽",
    "lbrbrak": "〔",
    "rbrbrak": "〕",
    "draftingarrow": "➛",
    "arrowbullet": "➢",
    "threedangle": "⟀",
    "whiteinwhitetriangle": "⟁",
    "perp": "⟂",
    "subsetcirc": "⟃",
    "supsetcirc": "⟄",
    "Lbag": "⟅",
    "Rbag": "⟆",
    "veedot": "⟇",
    "bsolhsub": "⟈",
    "suphsol": "⟉",
    "longdivision": "⟌",
    "Diamonddot": "⟐",
    "wedgedot": "⟑",
    "upin": "⟒",
    "pullback": "⟓",
    "pushout": "⟔",
    "leftouterjoin": "⟕",
    "rightouterjoin": "⟖",
    "fullouterjoin": "⟗",
    "bigbot": "⟘",
    "bigtop": "⟙",
    "DashVDash": "⟚",
    "dashVdash": "⟛",
    "multimapinv": "⟜",
    "vlongdash": "⟝",
    "longdashv": "⟞",
    "cirbot": "⟟",
    "lozengeminus": "⟠",
    "concavediamond": "⟡",
    "concavediamondtickleft": "⟢",
    "concavediamondtickright": "⟣",
    "whitesquaretickleft": "⟤",
    "whitesquaretickright": "⟥",
    "llbracket": "⟦",
    "rrbracket": "⟧",
    "langle": "⟨",
    "rangle": "⟩",
    "lang": "⟪",
    "rang": "⟫",
    "Lbrbrak": "〘",
    "Rbrbrak": "〙",
    "lgroup": "⟮",
    "rgroup": "⟯",
    "UUparrow": "⟰",
    "DDownarrow": "⟱",
    "acwgapcirclearrow": "⟲",
    "cwgapcirclearrow": "⟳",
    "rightarrowonoplus": "⟴",
    "longleftarrow": "⟵",
    "longrightarrow": "⟶",
    "longleftrightarrow": "⟷",
    "Longleftarrow": "⟸",
    "Longrightarrow": "⟹",
    "Longleftrightarrow": "⟺",
    "longmapsfrom": "⟻",
    "longmapsto": "⟼",
    "Longmapsfrom": "⟽",
    "Longmapsto": "⟾",
    "longrightsquigarrow": "⟿",
    "psur": "⤀",
    "nVtwoheadrightarrow": "⤁",
    "nvLeftarrow": "⤂",
    "nvRightarrow": "⤃",
    "nvLeftrightarrow": "⤄",
    "twoheadmapsto": "⤅",
    "Mapsfrom": "⤆",
    "Mapsto": "⤇",
    "downarrowbarred": "⤈",
    "uparrowbarred": "⤉",
    "Uuparrow": "⤊",
    "Ddownarrow": "⤋",
    "leftbkarrow": "⤌",
    "rightbkarrow": "⤍",
    "leftdbkarrow": "⤎",
    "dbkarow": "⤏",
    "drbkarow": "⤐",
    "rightdotarrow": "⤑",
    "UpArrowBar": "⤒",
    "DownArrowBar": "⤓",
    "pinj": "⤔",
    "finj": "⤕",
    "bij": "⤖",
    "nvtwoheadrightarrowtail": "⤗",
    "nVtwoheadrightarrowtail": "⤘",
    "lefttail": "⤙",
    "righttail": "⤚",
    "leftdbltail": "⤛",
    "rightdbltail": "⤜",
    "diamondleftarrow": "⤝",
    "rightarrowdiamond": "⤞",
    "diamondleftarrowbar": "⤟",
    "barrightarrowdiamond": "⤠",
    "nwsearrow": "⤡",
    "neswarrow": "⤢",
    "hknwarrow": "⤣",
    "hknearrow": "⤤",
    "hksearow": "⤥",
    "hkswarow": "⤦",
    "tona": "⤧",
    "toea": "⤨",
    "tosa": "⤩",
    "towa": "⤪",
    "rdiagovfdiag": "⤫",
    "fdiagovrdiag": "⤬",
    "seovnearrow": "⤭",
    "neovsearrow": "⤮",
    "fdiagovnearrow": "⤯",
    "rdiagovsearrow": "⤰",
    "neovnwarrow": "⤱",
    "nwovnearrow": "⤲",
    "leadsto": "⤳",
    "uprightcurvearrow": "⤴",
    "downrightcurvedarrow": "⤵",
    "leftdowncurvedarrow": "⤶",
    "rightdowncurvedarrow": "⤷",
    "cwrightarcarrow": "⤸",
    "acwleftarcarrow": "⤹",
    "acwoverarcarrow": "⤺",
    "acwunderarcarrow": "⤻",
    "curvearrowrightminus": "⤼",
    "curvearrowleftplus": "⤽",
    "cwundercurvearrow": "⤾",
    "ccwundercurvearrow": "⤿",
    "acwcirclearrow": "⥀",
    "cwcirclearrow": "⥁",
    "rightarrowshortleftarrow": "⥂",
    "leftarrowshortrightarrow": "⥃",
    "shortrightarrowleftarrow": "⥄",
    "rightarrowplus": "⥅",
    "leftarrowplus": "⥆",
    "rightarrowx": "⥇",
    "leftrightarrowcircle": "⥈",
    "twoheaduparrowcircle": "⥉",
    "leftrightharpoon": "⥊",
    "rightleftharpoon": "⥋",
    "updownharpoonrightleft": "⥌",
    "updownharpoonleftright": "⥍",
    "leftrightharpoonup": "⥎",
    "rightupdownharpoon": "⥏",
    "leftrightharpoondown": "⥐",
    "leftupdownharpoon": "⥑",
    "LeftVectorBar": "⥒",
    "RightVectorBar": "⥓",
    "RightUpVectorBar": "⥔",
    "RightDownVectorBar": "⥕",
    "DownLeftVectorBar": "⥖",
    "DownRightVectorBar": "⥗",
    "LeftUpVectorBar": "⥘",
    "LeftDownVectorBar": "⥙",
    "LeftTeeVector": "⥚",
    "RightTeeVector": "⥛",
    "RightUpTeeVector": "⥜",
    "RightDownTeeVector": "⥝",
    "DownLeftTeeVector": "⥞",
    "DownRightTeeVector": "⥟",
    "LeftUpTeeVector": "⥠",
    "LeftDownTeeVector": "⥡",
    "leftleftharpoons": "⥢",
    "upupharpoons": "⥣",
    "rightrightharpoons": "⥤",
    "downdownharpoons": "⥥",
    "leftrightharpoonsup": "⥦",
    "leftrightharpoonsdown": "⥧",
    "rightleftharpoonsup": "⥨",
    "rightleftharpoonsdown": "⥩",
    "leftbarharpoon": "⥪",
    "barleftharpoon": "⥫",
    "rightbarharpoon": "⥬",
    "barrightharpoon": "⥭",
    "updownharpoons": "⥮",
    "downupharpoons": "⥯",
    "rightimply": "⥰",
    "equalrightarrow": "⥱",
    "similarrightarrow": "⥲",
    "leftarrowsimilar": "⥳",
    "rightarrowsimilar": "⥴",
    "rightarrowapprox": "⥵",
    "ltlarr": "⥶",
    "leftarrowless": "⥷",
    "gtrarr": "⥸",
    "subrarr": "⥹",
    "leftarrowsubset": "⥺",
    "suplarr": "⥻",
    "strictfi": "⥼",
    "strictif": "⥽",
    "upfishtail": "⥾",
    "downfishtail": "⥿",
    "VERT": "⦀",
    "spot": "⦁",
    "typecolon": "⦂",
    "lBrace": "⦃",
    "rBrace": "⦄",
    "Lparen": "⦅",
    "Rparen": "⦆",
    "limg": "⦇",
    "rimg": "⦈",
    "lblot": "⦉",
    "rblot": "⦊",
    "lbrackubar": "⦋",
    "rbrackubar": "⦌",
    "lbrackultick": "⦍",
    "rbracklrtick": "⦎",
    "lbracklltick": "⦏",
    "rbrackurtick": "⦐",
    "langledot": "⦑",
    "rangledot": "⦒",
    "lparenless": "⦓",
    "rparengtr": "⦔",
    "Lparengtr": "⦕",
    "Rparenless": "⦖",
    "lblkbrbrak": "⦗",
    "rblkbrbrak": "⦘",
    "fourvdots": "⦙",
    "vzigzag": "⦚",
    "measuredangleleft": "⦛",
    "rightanglesqr": "⦜",
    "rightanglemdot": "⦝",
    "angles": "⦞",
    "angdnr": "⦟",
    "gtlpar": "⦠",
    "sphericalangleup": "⦡",
    "turnangle": "⦢",
    "revangle": "⦣",
    "angleubar": "⦤",
    "revangleubar": "⦥",
    "wideangledown": "⦦",
    "wideangleup": "⦧",
    "measanglerutone": "⦨",
    "measanglelutonw": "⦩",
    "measanglerdtose": "⦪",
    "measangleldtosw": "⦫",
    "measangleurtone": "⦬",
    "measangleultonw": "⦭",
    "measangledrtose": "⦮",
    "measangledltosw": "⦯",
    "revemptyset": "⦰",
    "emptysetobar": "⦱",
    "emptysetocirc": "⦲",
    "emptysetoarr": "⦳",
    "emptysetoarrl": "⦴",
    "circlehbar": "⦵",
    "circledvert": "⦶",
    "circledparallel": "⦷",
    "circledbslash": "⦸",
    "operp": "⦹",
    "obot": "⦺",
    "olcross": "⦻",
    "odotslashdot": "⦼",
    "uparrowoncircle": "⦽",
    "circledwhitebullet": "⦾",
    "circledbullet": "⦿",
    "circledless": "⧀",
    "circledgtr": "⧁",
    "cirscir": "⧂",
    "cirE": "⧃",
    "boxslash": "⧄",
    "boxbslash": "⧅",
    "boxast": "⧆",
    "boxcircle": "⧇",
    "boxbox": "⧈",
    "boxonbox": "⧉",
    "triangleodot": "⧊",
    "triangleubar": "⧋",
    "triangles": "⧌",
    "triangleserifs": "⧍",
    "rtriltri": "⧎",
    "LeftTriangleBar": "⧏",
    "RightTriangleBar": "⧐",
    "lfbowtie": "⧑",
    "rfbowtie": "⧒",
    "fbowtie": "⧓",
    "lftimes": "⧔",
    "rftimes": "⧕",
    "hourglass": "⧖",
    "blackhourglass": "⧗",
    "lvzigzag": "⧘",
    "rvzigzag": "⧙",
    "Lvzigzag": "⧚",
    "Rvzigzag": "⧛",
    "iinfin": "⧜",
    "tieinfty": "⧝",
    "nvinfty": "⧞",
    "multimapboth": "⧟",
    "laplac": "⧠",
    "lrtriangleeq": "⧡",
    "shuffle": "⧢",
    "eparsl": "⧣",
    "smeparsl": "⧤",
    "eqvparsl": "⧥",
    "gleichstark": "⧦",
    "thermod": "⧧",
    "downtriangleleftblack": "⧨",
    "downtrianglerightblack": "⧩",
    "blackdiamonddownarrow": "⧪",
    "blacklozenge": "⧫",
    "circledownarrow": "⧬",
    "blackcircledownarrow": "⧭",
    "errbarsquare": "⧮",
    "errbarblacksquare": "⧯",
    "errbardiamond": "⧰",
    "errbarblackdiamond": "⧱",
    "errbarcircle": "⧲",
    "errbarblackcircle": "⧳",
    "ruledelayed": "⧴",
    "setminus": "⧵",
    "dsol": "⧶",
    "rsolbar": "⧷",
    "xsol": "⧸",
    "zhide": "⧹",
    "doubleplus": "⧺",
    "tripleplus": "⧻",
    "lcurvyangle": "⧼",
    "rcurvyangle": "⧽",
    "tplus": "⧾",
    "tminus": "⧿",
    "bigodot": "⨀",
    "bigoplus": "⨁",
    "bigotimes": "⨂",
    "bigcupdot": "⨃",
    "biguplus": "⨄",
    "bigsqcap": "⨅",
    "bigsqcup": "⨆",
    "conjquant": "⨇",
    "disjquant": "⨈",
    "varprod": "⨉",
    "modtwosum": "⨊",
    "sumint": "⨋",
    "iiiint": "⨌",
    "intbar": "⨍",
    "intBar": "⨎",
    "fint": "⨏",
    "cirfnint": "⨐",
    "awint": "⨑",
    "rppolint": "⨒",
    "scpolint": "⨓",
    "npolint": "⨔",
    "pointint": "⨕",
    "sqint": "⨖",
    "intlarhk": "⨗",
    "intx": "⨘",
    "intcap": "⨙",
    "intcup": "⨚",
    "upint": "⨛",
    "lowint": "⨜",
    "Join": "⨝",
    "bigtriangleleft": "⨞",
    "zcmp": "⨟",
    "zpipe": "⨠",
    "zproject": "⨡",
    "ringplus": "⨢",
    "plushat": "⨣",
    "simplus": "⨤",
    "plusdot": "⨥",
    "plussim": "⨦",
    "plussubtwo": "⨧",
    "plustrif": "⨨",
    "commaminus": "⨩",
    "minusdot": "⨪",
    "minusfdots": "⨫",
    "minusrdots": "⨬",
    "opluslhrim": "⨭",
    "oplusrhrim": "⨮",
    "vectimes": "⨯",
    "dottimes": "⨰",
    "timesbar": "⨱",
    "btimes": "⨲",
    "smashtimes": "⨳",
    "otimeslhrim": "⨴",
    "otimesrhrim": "⨵",
    "otimeshat": "⨶",
    "Otimes": "⨷",
    "odiv": "⨸",
    "triangleplus": "⨹",
    "triangleminus": "⨺",
    "triangletimes": "⨻",
    "intprod": "⨼",
    "intprodr": "⨽",
    "fcmp": "⨾",
    "amalg": "⨿",
    "capdot": "⩀",
    "uminus": "⩁",
    "barcup": "⩂",
    "barcap": "⩃",
    "capwedge": "⩄",
    "cupvee": "⩅",
    "cupovercap": "⩆",
    "capovercup": "⩇",
    "cupbarcap": "⩈",
    "capbarcup": "⩉",
    "twocups": "⩊",
    "twocaps": "⩋",
    "closedvarcup": "⩌",
    "closedvarcap": "⩍",
    "Sqcap": "⩎",
    "Sqcup": "⩏",
    "closedvarcupsmashprod": "⩐",
    "wedgeodot": "⩑",
    "veeodot": "⩒",
    "Wedge": "⩓",
    "Vee": "⩔",
    "wedgeonwedge": "⩕",
    "veeonvee": "⩖",
    "bigslopedvee": "⩗",
    "bigslopedwedge": "⩘",
    "veeonwedge": "⩙",
    "wedgemidvert": "⩚",
    "veemidvert": "⩛",
    "midbarwedge": "⩜",
    "midbarvee": "⩝",
    "doublebarwedge": "⩞",
    "wedgebar": "⩟",
    "wedgedoublebar": "⩠",
    "varveebar": "⩡",
    "doublebarvee": "⩢",
    "veedoublebar": "⩣",
    "dsub": "⩤",
    "rsub": "⩥",
    "eqdot": "⩦",
    "dotequiv": "⩧",
    "equivVert": "⩨",
    "equivVvert": "⩩",
    "dotsim": "⩪",
    "simrdots": "⩫",
    "simminussim": "⩬",
    "congdot": "⩭",
    "asteq": "⩮",
    "hatapprox": "⩯",
    "approxeqq": "⩰",
    "eqqplus": "⩱",
    "pluseqq": "⩲",
    "eqqsim": "⩳",
    "Coloneqq": "⩴",
    "Equal": "⩵",
    "Same": "⩶",
    "ddotseq": "⩷",
    "equivDD": "⩸",
    "ltcir": "⩹",
    "gtcir": "⩺",
    "ltquest": "⩻",
    "gtquest": "⩼",
    "leqslant": "⩽",
    "geqslant": "⩾",
    "lesdot": "⩿",
    "gesdot": "⪀",
    "lesdoto": "⪁",
    "gesdoto": "⪂",
    "lesdotor": "⪃",
    "gesdotol": "⪄",
    "lessapprox": "⪅",
    "gtrapprox": "⪆",
    "lneq": "⪇",
    "gneq": "⪈",
    "lnapprox": "⪉",
    "gnapprox": "⪊",
    "lesseqqgtr": "⪋",
    "gtreqqless": "⪌",
    "lsime": "⪍",
    "gsime": "⪎",
    "lsimg": "⪏",
    "gsiml": "⪐",
    "lgE": "⪑",
    "glE": "⪒",
    "lesges": "⪓",
    "gesles": "⪔",
    "eqslantless": "⪕",
    "eqslantgtr": "⪖",
    "elsdot": "⪗",
    "egsdot": "⪘",
    "eqqless": "⪙",
    "eqqgtr": "⪚",
    "eqqslantless": "⪛",
    "eqqslantgtr": "⪜",
    "simless": "⪝",
    "simgtr": "⪞",
    "simlE": "⪟",
    "simgE": "⪠",
    "NestedLessLess": "⪡",
    "NestedGreaterGreater": "⪢",
    "partialmeetcontraction": "⪣",
    "glj": "⪤",
    "gla": "⪥",
    "leftslice": "⪦",
    "rightslice": "⪧",
    "lescc": "⪨",
    "gescc": "⪩",
    "smt": "⪪",
    "lat": "⪫",
    "smte": "⪬",
    "late": "⪭",
    "bumpeqq": "⪮",
    "preceq": "⪯",
    "succeq": "⪰",
    "precneq": "⪱",
    "succneq": "⪲",
    "preceqq": "⪳",
    "succeqq": "⪴",
    "precneqq": "⪵",
    "succneqq": "⪶",
    "precapprox": "⪷",
    "succapprox": "⪸",
    "precnapprox": "⪹",
    "succnapprox": "⪺",
    "llcurly": "⪻",
    "ggcurly": "⪼",
    "subsetdot": "⪽",
    "supsetdot": "⪾",
    "subsetplus": "⪿",
    "supsetplus": "⫀",
    "submult": "⫁",
    "supmult": "⫂",
    "subedot": "⫃",
    "supedot": "⫄",
    "subseteqq": "⫅",
    "supseteqq": "⫆",
    "subsim": "⫇",
    "supsim": "⫈",
    "subsetapprox": "⫉",
    "supsetapprox": "⫊",
    "subsetneqq": "⫋",
    "supsetneqq": "⫌",
    "lsqhook": "⫍",
    "rsqhook": "⫎",
    "csub": "⫏",
    "csup": "⫐",
    "csube": "⫑",
    "csupe": "⫒",
    "subsup": "⫓",
    "supsub": "⫔",
    "subsub": "⫕",
    "supsup": "⫖",
    "suphsub": "⫗",
    "supdsub": "⫘",
    "forkv": "⫙",
    "topfork": "⫚",
    "mlcp": "⫛",
    "forks": "⫝̸",
    "forksnot": "⫝",
    "shortlefttack": "⫞",
    "shortdowntack": "⫟",
    "shortuptack": "⫠",
    "perps": "⫡",
    "vDdash": "⫢",
    "dashV": "⫣",
    "Dashv": "⫤",
    "DashV": "⫥",
    "varVdash": "⫦",
    "Barv": "⫧",
    "vBar": "⫨",
    "vBarv": "⫩",
    "Top": "⫪",
    "Bot": "⫫",
    "Not": "⫬",
    "bNot": "⫭",
    "revnmid": "⫮",
    "cirmid": "⫯",
    "midcir": "⫰",
    "topcir": "⫱",
    "nhpar": "⫲",
    "parsim": "⫳",
    "interleave": "⫴",
    "nhVvert": "⫵",
    "threedotcolon": "⫶",
    "lllnest": "⫷",
    "gggnest": "⫸",
    "leqqslant": "⫹",
    "geqqslant": "⫺",
    "trslash": "⫻",
    "biginterleave": "⫼",
    "sslash": "⫽",
    "talloblong": "⫾",
    "bigtalloblong": "⫿",
    "": "⬑",
    "squaretopblack": "⬒",
    "squarebotblack": "⬓",
    "squareurblack": "⬔",
    "squarellblack": "⬕",
    "diamondleftblack": "⬖",
    "diamondrightblack": "⬗",
    "diamondtopblack": "⬘",
    "diamondbotblack": "⬙",
    "dottedsquare": "⬚",
    "vysmblksquare": "⬝",
    "vysmwhtsquare": "⬞",
    "pentagonblack": "⬟",
    "pentagon": "⬠",
    "varhexagon": "⬡",
    "varhexagonblack": "⬢",
    "hexagonblack": "⬣",
    "lgblkcircle": "⬤",
    "mdblkdiamond": "⬥",
    "mdwhtdiamond": "⬦",
    "mdblklozenge": "⬧",
    "mdwhtlozenge": "⬨",
    "smblkdiamond": "⬩",
    "smblklozenge": "⬪",
    "smwhtlozenge": "⬫",
    "blkhorzoval": "⬬",
    "whthorzoval": "⬭",
    "blkvertoval": "⬮",
    "whtvertoval": "⬯",
    "circleonleftarrow": "⬰",
    "leftthreearrows": "⬱",
    "leftarrowonoplus": "⬲",
    "longleftsquigarrow": "⬳",
    "nvtwoheadleftarrow": "⬴",
    "nVtwoheadleftarrow": "⬵",
    "twoheadmapsfrom": "⬶",
    "twoheadleftdbkarrow": "⬷",
    "leftdotarrow": "⬸",
    "nvleftarrowtail": "⬹",
    "nVleftarrowtail": "⬺",
    "twoheadleftarrowtail": "⬻",
    "nvtwoheadleftarrowtail": "⬼",
    "nVtwoheadleftarrowtail": "⬽",
    "leftarrowx": "⬾",
    "leftcurvedarrow": "⬿",
    "equalleftarrow": "⭀",
    "bsimilarleftarrow": "⭁",
    "leftarrowbackapprox": "⭂",
    "rightarrowgtr": "⭃",
    "rightarrowsupset": "⭄",
    "LLeftarrow": "⭅",
    "RRightarrow": "⭆",
    "bsimilarrightarrow": "⭇",
    "rightarrowbackapprox": "⭈",
    "similarleftarrow": "⭉",
    "leftarrowapprox": "⭊",
    "leftarrowbsimilar": "⭋",
    "rightarrowbsimilar": "⭌",
    "medwhitestar": "⭐",
    "medblackstar": "⭑",
    "smwhitestar": "⭒",
    "rightpentagonblack": "⭓",
    "rightpentagon": "⭔",
    "postalmark": "〒",
    "hzigzag": "〰",
    "mathbf{A}": "𝐀",
    "mathbf{B}": "𝐁",
    "mathbf{C}": "𝐂",
    "mathbf{D}": "𝐃",
    "mathbf{E}": "𝐄",
    "mathbf{F}": "𝐅",
    "mathbf{G}": "𝐆",
    "mathbf{H}": "𝐇",
    "mathbf{I}": "𝐈",
    "mathbf{J}": "𝐉",
    "mathbf{K}": "𝐊",
    "mathbf{L}": "𝐋",
    "mathbf{M}": "𝐌",
    "mathbf{N}": "𝐍",
    "mathbf{O}": "𝐎",
    "mathbf{P}": "𝐏",
    "mathbf{Q}": "𝐐",
    "mathbf{R}": "𝐑",
    "mathbf{S}": "𝐒",
    "mathbf{T}": "𝐓",
    "mathbf{U}": "𝐔",
    "mathbf{V}": "𝐕",
    "mathbf{W}": "𝐖",
    "mathbf{X}": "𝐗",
    "mathbf{Y}": "𝐘",
    "mathbf{Z}": "𝐙",
    "mathbf{a}": "𝐚",
    "mathbf{b}": "𝐛",
    "mathbf{c}": "𝐜",
    "mathbf{d}": "𝐝",
    "mathbf{e}": "𝐞",
    "mathbf{f}": "𝐟",
    "mathbf{g}": "𝐠",
    "mathbf{h}": "𝐡",
    "mathbf{i}": "𝐢",
    "mathbf{j}": "𝐣",
    "mathbf{k}": "𝐤",
    "mathbf{l}": "𝐥",
    "mathbf{m}": "𝐦",
    "mathbf{n}": "𝐧",
    "mathbf{o}": "𝐨",
    "mathbf{p}": "𝐩",
    "mathbf{q}": "𝐪",
    "mathbf{r}": "𝐫",
    "mathbf{s}": "𝐬",
    "mathbf{t}": "𝐭",
    "mathbf{u}": "𝐮",
    "mathbf{v}": "𝐯",
    "mathbf{w}": "𝐰",
    "mathbf{x}": "𝐱",
    "mathbf{y}": "𝐲",
    "mathbf{z}": "𝐳",
    "mathbfit{A}": "𝑨",
    "mathbfit{B}": "𝑩",
    "mathbfit{C}": "𝑪",
    "mathbfit{D}": "𝑫",
    "mathbfit{E}": "𝑬",
    "mathbfit{F}": "𝑭",
    "mathbfit{G}": "𝑮",
    "mathbfit{H}": "𝑯",
    "mathbfit{I}": "𝑰",
    "mathbfit{J}": "𝑱",
    "mathbfit{K}": "𝑲",
    "mathbfit{L}": "𝑳",
    "mathbfit{M}": "𝑴",
    "mathbfit{N}": "𝑵",
    "mathbfit{O}": "𝑶",
    "mathbfit{P}": "𝑷",
    "mathbfit{Q}": "𝑸",
    "mathbfit{R}": "𝑹",
    "mathbfit{S}": "𝑺",
    "mathbfit{T}": "𝑻",
    "mathbfit{U}": "𝑼",
    "mathbfit{V}": "𝑽",
    "mathbfit{W}": "𝑾",
    "mathbfit{X}": "𝑿",
    "mathbfit{Y}": "𝒀",
    "mathbfit{Z}": "𝒁",
    "mathbfit{a}": "𝒂",
    "mathbfit{b}": "𝒃",
    "mathbfit{c}": "𝒄",
    "mathbfit{d}": "𝒅",
    "mathbfit{e}": "𝒆",
    "mathbfit{f}": "𝒇",
    "mathbfit{g}": "𝒈",
    "mathbfit{h}": "𝒉",
    "mathbfit{i}": "𝒊",
    "mathbfit{j}": "𝒋",
    "mathbfit{k}": "𝒌",
    "mathbfit{l}": "𝒍",
    "mathbfit{m}": "𝒎",
    "mathbfit{n}": "𝒏",
    "mathbfit{o}": "𝒐",
    "mathbfit{p}": "𝒑",
    "mathbfit{q}": "𝒒",
    "mathbfit{r}": "𝒓",
    "mathbfit{s}": "𝒔",
    "mathbfit{t}": "𝒕",
    "mathbfit{u}": "𝒖",
    "mathbfit{v}": "𝒗",
    "mathbfit{w}": "𝒘",
    "mathbfit{x}": "𝒙",
    "mathbfit{y}": "𝒚",
    "mathbfit{z}": "𝒛",
    "mathcal{A}": "𝒜",
    "mathcal{C}": "𝒞",
    "mathcal{D}": "𝒟",
    "mathcal{G}": "𝒢",
    "mathcal{J}": "𝒥",
    "mathcal{K}": "𝒦",
    "mathcal{N}": "𝒩",
    "mathcal{O}": "𝒪",
    "mathcal{P}": "𝒫",
    "mathcal{Q}": "𝒬",
    "mathcal{S}": "𝒮",
    "mathcal{T}": "𝒯",
    "mathcal{U}": "𝒰",
    "mathcal{V}": "𝒱",
    "mathcal{W}": "𝒲",
    "mathcal{X}": "𝒳",
    "mathcal{Y}": "𝒴",
    "mathcal{Z}": "𝒵",
    "mathcal{a}": "𝒶",
    "mathcal{b}": "𝒷",
    "mathcal{c}": "𝒸",
    "mathcal{d}": "𝒹",
    "mathcal{f}": "𝒻",
    "mathcal{h}": "𝒽",
    "mathcal{i}": "𝒾",
    "mathcal{j}": "𝒿",
    "mathcal{k}": "𝓀",
    "mathcal{l}": "𝓁",
    "mathcal{m}": "𝓂",
    "mathcal{n}": "𝓃",
    "mathcal{p}": "𝓅",
    "mathcal{q}": "𝓆",
    "mathcal{r}": "𝓇",
    "mathcal{s}": "𝓈",
    "mathcal{t}": "𝓉",
    "mathcal{u}": "𝓊",
    "mathcal{v}": "𝓋",
    "mathcal{w}": "𝓌",
    "mathcal{x}": "𝓍",
    "mathcal{y}": "𝓎",
    "mathcal{z}": "𝓏",
    "mbfscrA": "𝓐",
    "mbfscrB": "𝓑",
    "mbfscrC": "𝓒",
    "mbfscrD": "𝓓",
    "mbfscrE": "𝓔",
    "mbfscrF": "𝓕",
    "mbfscrG": "𝓖",
    "mbfscrH": "𝓗",
    "mbfscrI": "𝓘",
    "mbfscrJ": "𝓙",
    "mbfscrK": "𝓚",
    "mbfscrL": "𝓛",
    "mbfscrM": "𝓜",
    "mbfscrN": "𝓝",
    "mbfscrO": "𝓞",
    "mbfscrP": "𝓟",
    "mbfscrQ": "𝓠",
    "mbfscrR": "𝓡",
    "mbfscrS": "𝓢",
    "mbfscrT": "𝓣",
    "mbfscrU": "𝓤",
    "mbfscrV": "𝓥",
    "mbfscrW": "𝓦",
    "mbfscrX": "𝓧",
    "mbfscrY": "𝓨",
    "mbfscrZ": "𝓩",
    "mbfscra": "𝓪",
    "mbfscrb": "𝓫",
    "mbfscrc": "𝓬",
    "mbfscrd": "𝓭",
    "mbfscre": "𝓮",
    "mbfscrf": "𝓯",
    "mbfscrg": "𝓰",
    "mbfscrh": "𝓱",
    "mbfscri": "𝓲",
    "mbfscrj": "𝓳",
    "mbfscrk": "𝓴",
    "mbfscrl": "𝓵",
    "mbfscrm": "𝓶",
    "mbfscrn": "𝓷",
    "mbfscro": "𝓸",
    "mbfscrp": "𝓹",
    "mbfscrq": "𝓺",
    "mbfscrr": "𝓻",
    "mbfscrs": "𝓼",
    "mbfscrt": "𝓽",
    "mbfscru": "𝓾",
    "mbfscrv": "𝓿",
    "mbfscrw": "𝔀",
    "mbfscrx": "𝔁",
    "mbfscry": "𝔂",
    "mbfscrz": "𝔃",
    "mathfrak{A}": "𝔄",
    "mathfrak{B}": "𝔅",
    "mathfrak{D}": "𝔇",
    "mathfrak{E}": "𝔈",
    "mathfrak{F}": "𝔉",
    "mathfrak{G}": "𝔊",
    "mathfrak{J}": "𝔍",
    "mathfrak{K}": "𝔎",
    "mathfrak{L}": "𝔏",
    "mathfrak{M}": "𝔐",
    "mathfrak{N}": "𝔑",
    "mathfrak{O}": "𝔒",
    "mathfrak{P}": "𝔓",
    "mathfrak{Q}": "𝔔",
    "mathfrak{S}": "𝔖",
    "mathfrak{T}": "𝔗",
    "mathfrak{U}": "𝔘",
    "mathfrak{V}": "𝔙",
    "mathfrak{W}": "𝔚",
    "mathfrak{X}": "𝔛",
    "mathfrak{Y}": "𝔜",
    "mathfrak{a}": "𝔞",
    "mathfrak{b}": "𝔟",
    "mathfrak{c}": "𝔠",
    "mathfrak{d}": "𝔡",
    "mathfrak{e}": "𝔢",
    "mathfrak{f}": "𝔣",
    "mathfrak{g}": "𝔤",
    "mathfrak{h}": "𝔥",
    "mathfrak{i}": "𝔦",
    "mathfrak{j}": "𝔧",
    "mathfrak{k}": "𝔨",
    "mathfrak{l}": "𝔩",
    "mathfrak{m}": "𝔪",
    "mathfrak{n}": "𝔫",
    "mathfrak{o}": "𝔬",
    "mathfrak{p}": "𝔭",
    "mathfrak{q}": "𝔮",
    "mathfrak{r}": "𝔯",
    "mathfrak{s}": "𝔰",
    "mathfrak{t}": "𝔱",
    "mathfrak{u}": "𝔲",
    "mathfrak{v}": "𝔳",
    "mathfrak{w}": "𝔴",
    "mathfrak{x}": "𝔵",
    "mathfrak{y}": "𝔶",
    "mathfrak{z}": "𝔷",
    "mathbb{A}": "𝔸",
    "mathbb{B}": "𝔹",
    "mathbb{D}": "𝔻",
    "mathbb{E}": "𝔼",
    "mathbb{F}": "𝔽",
    "mathbb{G}": "𝔾",
    "mathbb{I}": "𝕀",
    "mathbb{J}": "𝕁",
    "mathbb{K}": "𝕂",
    "mathbb{L}": "𝕃",
    "mathbb{M}": "𝕄",
    "mathbb{O}": "𝕆",
    "mathbb{S}": "𝕊",
    "mathbb{T}": "𝕋",
    "mathbb{U}": "𝕌",
    "mathbb{V}": "𝕍",
    "mathbb{W}": "𝕎",
    "mathbb{X}": "𝕏",
    "mathbb{Y}": "𝕐",
    "mathbb{a}": "𝕒",
    "mathbb{b}": "𝕓",
    "mathbb{c}": "𝕔",
    "mathbb{d}": "𝕕",
    "mathbb{e}": "𝕖",
    "mathbb{f}": "𝕗",
    "mathbb{g}": "𝕘",
    "mathbb{h}": "𝕙",
    "mathbb{i}": "𝕚",
    "mathbb{j}": "𝕛",
    "mathbb{k}": "𝕜",
    "mathbb{l}": "𝕝",
    "mathbb{m}": "𝕞",
    "mathbb{n}": "𝕟",
    "mathbb{o}": "𝕠",
    "mathbb{p}": "𝕡",
    "mathbb{q}": "𝕢",
    "mathbb{r}": "𝕣",
    "mathbb{s}": "𝕤",
    "mathbb{t}": "𝕥",
    "mathbb{u}": "𝕦",
    "mathbb{v}": "𝕧",
    "mathbb{w}": "𝕨",
    "mathbb{x}": "𝕩",
    "mathbb{y}": "𝕪",
    "mathbb{z}": "𝕫",
    "mbffrakA": "𝕬",
    "mbffrakB": "𝕭",
    "mbffrakC": "𝕮",
    "mbffrakD": "𝕯",
    "mbffrakE": "𝕰",
    "mbffrakF": "𝕱",
    "mbffrakG": "𝕲",
    "mbffrakH": "𝕳",
    "mbffrakI": "𝕴",
    "mbffrakJ": "𝕵",
    "mbffrakK": "𝕶",
    "mbffrakL": "𝕷",
    "mbffrakM": "𝕸",
    "mbffrakN": "𝕹",
    "mbffrakO": "𝕺",
    "mbffrakP": "𝕻",
    "mbffrakQ": "𝕼",
    "mbffrakR": "𝕽",
    "mbffrakS": "𝕾",
    "mbffrakT": "𝕿",
    "mbffrakU": "𝖀",
    "mbffrakV": "𝖁",
    "mbffrakW": "𝖂",
    "mbffrakX": "𝖃",
    "mbffrakY": "𝖄",
    "mbffrakZ": "𝖅",
    "mbffraka": "𝖆",
    "mbffrakb": "𝖇",
    "mbffrakc": "𝖈",
    "mbffrakd": "𝖉",
    "mbffrake": "𝖊",
    "mbffrakf": "𝖋",
    "mbffrakg": "𝖌",
    "mbffrakh": "𝖍",
    "mbffraki": "𝖎",
    "mbffrakj": "𝖏",
    "mbffrakk": "𝖐",
    "mbffrakl": "𝖑",
    "mbffrakm": "𝖒",
    "mbffrakn": "𝖓",
    "mbffrako": "𝖔",
    "mbffrakp": "𝖕",
    "mbffrakq": "𝖖",
    "mbffrakr": "𝖗",
    "mbffraks": "𝖘",
    "mbffrakt": "𝖙",
    "mbffraku": "𝖚",
    "mbffrakv": "𝖛",
    "mbffrakw": "𝖜",
    "mbffrakx": "𝖝",
    "mbffraky": "𝖞",
    "mbffrakz": "𝖟",
    "mathsf{A}": "𝖠",
    "mathsf{B}": "𝖡",
    "mathsf{C}": "𝖢",
    "mathsf{D}": "𝖣",
    "mathsf{E}": "𝖤",
    "mathsf{F}": "𝖥",
    "mathsf{G}": "𝖦",
    "mathsf{H}": "𝖧",
    "mathsf{I}": "𝖨",
    "mathsf{J}": "𝖩",
    "mathsf{K}": "𝖪",
    "mathsf{L}": "𝖫",
    "mathsf{M}": "𝖬",
    "mathsf{N}": "𝖭",
    "mathsf{O}": "𝖮",
    "mathsf{P}": "𝖯",
    "mathsf{Q}": "𝖰",
    "mathsf{R}": "𝖱",
    "mathsf{S}": "𝖲",
    "mathsf{T}": "𝖳",
    "mathsf{U}": "𝖴",
    "mathsf{V}": "𝖵",
    "mathsf{W}": "𝖶",
    "mathsf{X}": "𝖷",
    "mathsf{Y}": "𝖸",
    "mathsf{Z}": "𝖹",
    "mathsf{a}": "𝖺",
    "mathsf{b}": "𝖻",
    "mathsf{c}": "𝖼",
    "mathsf{d}": "𝖽",
    "mathsf{e}": "𝖾",
    "mathsf{f}": "𝖿",
    "mathsf{g}": "𝗀",
    "mathsf{h}": "𝗁",
    "mathsf{i}": "𝗂",
    "mathsf{j}": "𝗃",
    "mathsf{k}": "𝗄",
    "mathsf{l}": "𝗅",
    "mathsf{m}": "𝗆",
    "mathsf{n}": "𝗇",
    "mathsf{o}": "𝗈",
    "mathsf{p}": "𝗉",
    "mathsf{q}": "𝗊",
    "mathsf{r}": "𝗋",
    "mathsf{s}": "𝗌",
    "mathsf{t}": "𝗍",
    "mathsf{u}": "𝗎",
    "mathsf{v}": "𝗏",
    "mathsf{w}": "𝗐",
    "mathsf{x}": "𝗑",
    "mathsf{y}": "𝗒",
    "mathsf{z}": "𝗓",
    "mathsfbf{A}": "𝗔",
    "mathsfbf{B}": "𝗕",
    "mathsfbf{C}": "𝗖",
    "mathsfbf{D}": "𝗗",
    "mathsfbf{E}": "𝗘",
    "mathsfbf{F}": "𝗙",
    "mathsfbf{G}": "𝗚",
    "mathsfbf{H}": "𝗛",
    "mathsfbf{I}": "𝗜",
    "mathsfbf{J}": "𝗝",
    "mathsfbf{K}": "𝗞",
    "mathsfbf{L}": "𝗟",
    "mathsfbf{M}": "𝗠",
    "mathsfbf{N}": "𝗡",
    "mathsfbf{O}": "𝗢",
    "mathsfbf{P}": "𝗣",
    "mathsfbf{Q}": "𝗤",
    "mathsfbf{R}": "𝗥",
    "mathsfbf{S}": "𝗦",
    "mathsfbf{T}": "𝗧",
    "mathsfbf{U}": "𝗨",
    "mathsfbf{V}": "𝗩",
    "mathsfbf{W}": "𝗪",
    "mathsfbf{X}": "𝗫",
    "mathsfbf{Y}": "𝗬",
    "mathsfbf{Z}": "𝗭",
    "mathsfbf{a}": "𝗮",
    "mathsfbf{b}": "𝗯",
    "mathsfbf{c}": "𝗰",
    "mathsfbf{d}": "𝗱",
    "mathsfbf{e}": "𝗲",
    "mathsfbf{f}": "𝗳",
    "mathsfbf{g}": "𝗴",
    "mathsfbf{h}": "𝗵",
    "mathsfbf{i}": "𝗶",
    "mathsfbf{j}": "𝗷",
    "mathsfbf{k}": "𝗸",
    "mathsfbf{l}": "𝗹",
    "mathsfbf{m}": "𝗺",
    "mathsfbf{n}": "𝗻",
    "mathsfbf{o}": "𝗼",
    "mathsfbf{p}": "𝗽",
    "mathsfbf{q}": "𝗾",
    "mathsfbf{r}": "𝗿",
    "mathsfbf{s}": "𝘀",
    "mathsfbf{t}": "𝘁",
    "mathsfbf{u}": "𝘂",
    "mathsfbf{v}": "𝘃",
    "mathsfbf{w}": "𝘄",
    "mathsfbf{x}": "𝘅",
    "mathsfbf{y}": "𝘆",
    "mathsfbf{z}": "𝘇",
    "mathsfit{A}": "𝘈",
    "mathsfit{B}": "𝘉",
    "mathsfit{C}": "𝘊",
    "mathsfit{D}": "𝘋",
    "mathsfit{E}": "𝘌",
    "mathsfit{F}": "𝘍",
    "mathsfit{G}": "𝘎",
    "mathsfit{H}": "𝘏",
    "mathsfit{I}": "𝘐",
    "mathsfit{J}": "𝘑",
    "mathsfit{K}": "𝘒",
    "mathsfit{L}": "𝘓",
    "mathsfit{M}": "𝘔",
    "mathsfit{N}": "𝘕",
    "mathsfit{O}": "𝘖",
    "mathsfit{P}": "𝘗",
    "mathsfit{Q}": "𝘘",
    "mathsfit{R}": "𝘙",
    "mathsfit{S}": "𝘚",
    "mathsfit{T}": "𝘛",
    "mathsfit{U}": "𝘜",
    "mathsfit{V}": "𝘝",
    "mathsfit{W}": "𝘞",
    "mathsfit{X}": "𝘟",
    "mathsfit{Y}": "𝘠",
    "mathsfit{Z}": "𝘡",
    "mathsfit{a}": "𝘢",
    "mathsfit{b}": "𝘣",
    "mathsfit{c}": "𝘤",
    "mathsfit{d}": "𝘥",
    "mathsfit{e}": "𝘦",
    "mathsfit{f}": "𝘧",
    "mathsfit{g}": "𝘨",
    "mathsfit{h}": "𝘩",
    "mathsfit{i}": "𝘪",
    "mathsfit{j}": "𝘫",
    "mathsfit{k}": "𝘬",
    "mathsfit{l}": "𝘭",
    "mathsfit{m}": "𝘮",
    "mathsfit{n}": "𝘯",
    "mathsfit{o}": "𝘰",
    "mathsfit{p}": "𝘱",
    "mathsfit{q}": "𝘲",
    "mathsfit{r}": "𝘳",
    "mathsfit{s}": "𝘴",
    "mathsfit{t}": "𝘵",
    "mathsfit{u}": "𝘶",
    "mathsfit{v}": "𝘷",
    "mathsfit{w}": "𝘸",
    "mathsfit{x}": "𝘹",
    "mathsfit{y}": "𝘺",
    "mathsfit{z}": "𝘻",
    "mathsfbfit{A}": "𝘼",
    "mathsfbfit{B}": "𝘽",
    "mathsfbfit{C}": "𝘾",
    "mathsfbfit{D}": "𝘿",
    "mathsfbfit{E}": "𝙀",
    "mathsfbfit{F}": "𝙁",
    "mathsfbfit{G}": "𝙂",
    "mathsfbfit{H}": "𝙃",
    "mathsfbfit{I}": "𝙄",
    "mathsfbfit{J}": "𝙅",
    "mathsfbfit{K}": "𝙆",
    "mathsfbfit{L}": "𝙇",
    "mathsfbfit{M}": "𝙈",
    "mathsfbfit{N}": "𝙉",
    "mathsfbfit{O}": "𝙊",
    "mathsfbfit{P}": "𝙋",
    "mathsfbfit{Q}": "𝙌",
    "mathsfbfit{R}": "𝙍",
    "mathsfbfit{S}": "𝙎",
    "mathsfbfit{T}": "𝙏",
    "mathsfbfit{U}": "𝙐",
    "mathsfbfit{V}": "𝙑",
    "mathsfbfit{W}": "𝙒",
    "mathsfbfit{X}": "𝙓",
    "mathsfbfit{Y}": "𝙔",
    "mathsfbfit{Z}": "𝙕",
    "mathsfbfit{a}": "𝙖",
    "mathsfbfit{b}": "𝙗",
    "mathsfbfit{c}": "𝙘",
    "mathsfbfit{d}": "𝙙",
    "mathsfbfit{e}": "𝙚",
    "mathsfbfit{f}": "𝙛",
    "mathsfbfit{g}": "𝙜",
    "mathsfbfit{h}": "𝙝",
    "mathsfbfit{i}": "𝙞",
    "mathsfbfit{j}": "𝙟",
    "mathsfbfit{k}": "𝙠",
    "mathsfbfit{l}": "𝙡",
    "mathsfbfit{m}": "𝙢",
    "mathsfbfit{n}": "𝙣",
    "mathsfbfit{o}": "𝙤",
    "mathsfbfit{p}": "𝙥",
    "mathsfbfit{q}": "𝙦",
    "mathsfbfit{r}": "𝙧",
    "mathsfbfit{s}": "𝙨",
    "mathsfbfit{t}": "𝙩",
    "mathsfbfit{u}": "𝙪",
    "mathsfbfit{v}": "𝙫",
    "mathsfbfit{w}": "𝙬",
    "mathsfbfit{x}": "𝙭",
    "mathsfbfit{y}": "𝙮",
    "mathsfbfit{z}": "𝙯",
    "mbfAlpha": "𝚨",
    "mbfBeta": "𝚩",
    "mbfEpsilon": "𝚬",
    "mbfZeta": "𝚭",
    "mbfEta": "𝚮",
    "mbfIota": "𝚰",
    "mbfKappa": "𝚱",
    "mbfMu": "𝚳",
    "mbfNu": "𝚴",
    "mbfOmicron": "𝚶",
    "mbfRho": "𝚸",
    "mbfvarTheta": "𝚹",
    "mbfTau": "𝚻",
    "mbfChi": "𝚾",
    "mbfnabla": "𝛁",
    "mbfomicron": "𝛐",
    "mbfpartial": "𝛛",
    "mbfvarkappa": "𝛞",
    "mitAlpha": "𝛢",
    "mitBeta": "𝛣",
    "mitEpsilon": "𝛦",
    "mitZeta": "𝛧",
    "mitEta": "𝛨",
    "mitIota": "𝛪",
    "mitKappa": "𝛫",
    "mitMu": "𝛭",
    "mitNu": "𝛮",
    "mitOmicron": "𝛰",
    "mitRho": "𝛲",
    "mitvarTheta": "𝛳",
    "mitTau": "𝛵",
    "mitChi": "𝛸",
    "mitnabla": "𝛻",
    "mitomicron": "𝜊",
    "mbfitAlpha": "𝜜",
    "mbfitBeta": "𝜝",
    "mbfitEpsilon": "𝜠",
    "mbfitZeta": "𝜡",
    "mbfitEta": "𝜢",
    "mbfitIota": "𝜤",
    "mbfitKappa": "𝜥",
    "mbfitMu": "𝜧",
    "mbfitNu": "𝜨",
    "mbfitOmicron": "𝜪",
    "mbfitRho": "𝜬",
    "mbfitvarTheta": "𝜭",
    "mbfitTau": "𝜯",
    "mbfitChi": "𝜲",
    "mbfitnabla": "𝜵",
    "mbfitomicron": "𝝄",
    "mbfitpartial": "𝝏",
    "mbfitvarkappa": "𝝒",
    "mbfsansAlpha": "𝝖",
    "mbfsansBeta": "𝝗",
    "mbfsansEpsilon": "𝝚",
    "mbfsansZeta": "𝝛",
    "mbfsansEta": "𝝜",
    "mbfsansIota": "𝝞",
    "mbfsansKappa": "𝝟",
    "mbfsansMu": "𝝡",
    "mbfsansNu": "𝝢",
    "mbfsansOmicron": "𝝤",
    "mbfsansRho": "𝝦",
    "mbfsansvarTheta": "𝝧",
    "mbfsansTau": "𝝩",
    "mbfsansChi": "𝝬",
    "mbfsansnabla": "𝝯",
    "mbfsansomicron": "𝝾",
    "mbfsanspartial": "𝞉",
    "mbfsansvarkappa": "𝞌",
    "mbfitsansAlpha": "𝞐",
    "mbfitsansBeta": "𝞑",
    "mbfitsansEpsilon": "𝞔",
    "mbfitsansZeta": "𝞕",
    "mbfitsansEta": "𝞖",
    "mbfitsansIota": "𝞘",
    "mbfitsansKappa": "𝞙",
    "mbfitsansMu": "𝞛",
    "mbfitsansNu": "𝞜",
    "mbfitsansOmicron": "𝞞",
    "mbfitsansRho": "𝞠",
    "mbfitsansvarTheta": "𝞡",
    "mbfitsansTau": "𝞣",
    "mbfitsansChi": "𝞦",
    "mbfitsansnabla": "𝞩",
    "mbfitsansomicron": "𝞸",
    "mbfitsanspartial": "𝟃",
    "mbfitsansvarkappa": "𝟆",
    "mbfDigamma": "𝟊",
    "mbfdigamma": "𝟋",
}
